# Portobello 
A collection of (human-memory friendly) troubleshooting tools that might be needed for someone with limited machine permissions but the ability to run python.

## Getting Started 
TBD

### Prerequisites 
RHEL: yum install python-devel openldap-devel
Debian: ?
Windows: ?
Mac: ?

### Installation
pip install portobello

## Usage
portobello/pobo netstat (follow instructions)

portobello/pobo ldap (follow instructions)

portobello/pobo help

## Contributing
Please email me with suggestions, requests etc.

## License
GPL-3.
